@@ -1,5 +1,29 @@
 var NAVTREEINDEX2 =
 {
+"group__aom__encoder.html#ga790f05ad7832f2614a13fd60bd3430fe":[12,1,0,0,59],
+"group__aom__encoder.html#ga7a55a46970c074b761319c5c46d87b6e":[12,1,0,0,38],
+"group__aom__encoder.html#ga801f5eb2cb93da19a2f347ae7a44166a":[12,1,0,0,84],
+"group__aom__encoder.html#ga834aa2b6069db7cc53b0a6e6b23ab557":[12,1,0,0,74],
+"group__aom__encoder.html#ga88539c1f9e72d6ab6f8802ff265539dd":[12,1,0,0,52],
+"group__aom__encoder.html#ga8a09d2e568a6727f6dcfa189dcb64dc0":[12,1,0,0,66],
+"group__aom__encoder.html#ga8ac829090566737c469a7147207e8855":[12,1,0,0,50],
+"group__aom__encoder.html#ga8f20643dbd528f92fc0ecd96d9726d09":[12,1,0,0,71],
+"group__aom__encoder.html#ga900ebe22eaa0f9296c4a876316fd4d82":[12,1,0,0,69],
+"group__aom__encoder.html#ga98480541d93f77481d44dfb0896fcdc5":[12,1,0,0,44],
+"group__aom__encoder.html#ga9e2f989737d63ddf4e987a525d186a46":[12,1,0,0,35],
+"group__aom__encoder.html#ga9f3d7cfaa6290b207c0ce360ed63ae45":[12,1,0,0,48],
+"group__aom__encoder.html#gaa4bc8ae2b977b73f0ef57ba428ca1d2c":[12,1,0,0,33],
+"group__aom__encoder.html#gaa81cc31f95fd463f51a158050d267a36":[12,1,0,0,39],
+"group__aom__encoder.html#gaaef6fe76991abf87edd2f296eee999f8":[12,1,0,0,34],
+"group__aom__encoder.html#gaafd352cc596fab5388558950f8bbe739":[12,1,0,0,86],
+"group__aom__encoder.html#gab64a195ea67269e704df30e39a22ca42":[12,1,0,0,72],
+"group__aom__encoder.html#gab9478e27301dfb5581f8bdf9efb40f3e":[12,1,0,0,63],
+"group__aom__encoder.html#gac18e4b6e5fd6cb617a2674cf3de3f57e":[12,1,0,0,70],
+"group__aom__encoder.html#gac5a69f04b0bc88f755587a1da815d754":[12,1,0,0,41],
+"group__aom__encoder.html#gaca3421fd8424ed3ab48704748a12c9d1":[12,1,0,0,51],
+"group__aom__encoder.html#gacd5a13523326346771b2cf343cea96be":[12,1,0,0,75],
+"group__aom__encoder.html#gacfd479b87a0dc8cb0602268f9dca37ce":[12,1,0,0,60],
+"group__aom__encoder.html#gad04799a74215e1b9609f7ccd1766f8c9":[12,1,0,0,37],
 "group__aom__encoder.html#gad09f5b034137ba0981dd5f2dc075b27f":[12,1,0,0,56],
 "group__aom__encoder.html#gad69c1d6aa10530991eeb1a3f0a818cba":[12,1,0,0,85],
 "group__aom__encoder.html#gadb34e02e5b029504370f99a886371710":[12,1,0,0,58],
@@ -78,6 +102,7 @@ var NAVTREEINDEX2 =
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a57f2f2a54f593b398a5e97db7982f817":[12,1,0,0,82,22],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a5afff92787c68c2b5c50e3cfb9938504":[12,1,0,0,82,55],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a5e82346d8463bf758967abb0d03ebc88":[12,1,0,0,82,70],
+"group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a5ee3ade5f178f10dc29fa0e672a7a62f":[12,1,0,0,82,143],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a637ebd78bd66a38f22e6d149192c35ed":[12,1,0,0,82,138],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a643067b985c437490d6248decad39235":[12,1,0,0,82,74],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5a65f19811dc9057230d991647fac243b0":[12,1,0,0,82,39],
@@ -149,6 +174,7 @@ var NAVTREEINDEX2 =
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ae611944ba148b6446d4387dd9b452917":[12,1,0,0,82,52],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5ae63993934cdc5aa36efeec4df87a577e":[12,1,0,0,82,51],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aeb92db47fea74d34938668ee62bb565e":[12,1,0,0,82,89],
+"group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aedcf0d465066cf87f0bf81a637a8e0a4":[12,1,0,0,82,142],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5aef4facbd3745aa7f2a604faaf68316ff":[12,1,0,0,82,16],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5af341538631ffe2ac2b562c8b5336a10a":[12,1,0,0,82,95],
 "group__aom__encoder.html#ggae78dde67a6d78f332e9bdba0dde42db5af3db44e9871c69defc5ae2cc6c5e3ba0":[12,1,0,0,82,59],
@@ -223,31 +249,5 @@ var NAVTREEINDEX2 =
 "group__codec.html#ggaaae61e0f8663e6137f1e228757248e7caa4328d9fc527a3fd3cf76eb54e3db1a2":[12,0,32,2],
 "group__codec.html#ggaaae61e0f8663e6137f1e228757248e7cac4a4eea6394661cef74abf674c12cfa8":[12,0,32,4],
 "group__codec.html#ggaaae61e0f8663e6137f1e228757248e7caf145dc2f86014a08ebad36ac2b140001":[12,0,32,0],
-"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61a17127133dafcd42b1d792770981d67d0":[12,0,34,1],
-"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61a5abd24080a18d4f7e33217d93a73e968":[12,0,34,0],
-"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61aaabb4d9ad771b2fa177ff6fb5437b179":[12,0,34,2],
-"group__codecs.html":[12,1],
-"group__coefficient__coding.html":[12,2,5],
-"group__coefficient__coding.html#ga0076c2c06ae74fd7b00193d4aa2f1d46":[12,2,5,4],
-"group__coefficient__coding.html#ga1618c5468421234169f9b285bc70a59c":[12,2,5,13],
-"group__coefficient__coding.html#ga1f9147fbeb6681f1f2ffd99806c93526":[12,2,5,0],
-"group__coefficient__coding.html#ga225614c4ff1863904ee8a80e0d971cc4":[12,2,5,12],
-"group__coefficient__coding.html#ga24b28c5ec4bc705cc58a7655c8218e4d":[12,2,5,3],
-"group__coefficient__coding.html#ga2afb7e8b3781bec12c44908fc5eaff51":[12,2,5,2],
-"group__coefficient__coding.html#ga4bd51731afdd25275377807e067c9d12":[12,2,5,7],
-"group__coefficient__coding.html#ga50e1752ad80721912848f6087b7b1025":[12,2,5,5],
-"group__coefficient__coding.html#ga8bc502fea9846765fba7de6a8fd90279":[12,2,5,10],
-"group__coefficient__coding.html#ga99f06925f4adb19ffb5fcbc12745ab94":[12,2,5,11],
-"group__coefficient__coding.html#gab27521d24faa93e58a1ce487b1e8f626":[12,2,5,9],
-"group__coefficient__coding.html#gabb195b5ee31923fbd15fe4caaf466278":[12,2,5,1],
-"group__coefficient__coding.html#gad0c28d34dad6636237409bf2e1ee2014":[12,2,5,6],
-"group__coefficient__coding.html#gae0b8d3b37b0b43f1cfbd0f91cc4cc991":[12,2,5,8],
-"group__cyclic__refresh.html":[12,2,9],
-"group__cyclic__refresh.html#ga1e8e194fae8285692651fb856b49c185":[12,2,9,2],
-"group__cyclic__refresh.html#ga320b85772ac318291cc2bb14c249a1d8":[12,2,9,8],
-"group__cyclic__refresh.html#ga35ec71ccbbc64bcb31ed02229dfe9ae0":[12,2,9,4],
-"group__cyclic__refresh.html#ga3703e9a518f8f17e7b6b601a456dbde8":[12,2,9,1],
-"group__cyclic__refresh.html#gaa4acc60c7ec3fc459b5ce65920493823":[12,2,9,6],
-"group__cyclic__refresh.html#gab14ed0139e8ebd0177d8a4b9c1e273ce":[12,2,9,7],
-"group__cyclic__refresh.html#gab63536700b85e6560aed37f0b8afbcaf":[12,2,9,5]
+"group__codec.html#ggac34a24f7c6c0fef7518aed0da4425f61a17127133dafcd42b1d792770981d67d0":[12,0,34,1]
 };
